#ifndef _LOGIKBUTTONS_H_
#define _LOGIKBUTTONS_H_

#include <qwidget.h>
#include <qbitmap.h>
#include <kwin/kwinbutton.h>

namespace KWinInternal
{
  class KapturButton : public KWinWidgetButton
  {
    Q_OBJECT

    public:
      KapturButton(QWidget * parent, const QString& tip);

      virtual ~KapturButton();

      virtual QSize sizeHint() const;
      virtual QSize minimumSizeHint() const;

    protected:
      virtual void clickEvent(int button) = 0;

      void setBitmap(const QBitmap &);

      void mousePressEvent(QMouseEvent *);
      void mouseReleaseEvent(QMouseEvent *);
      void enterEvent(QEvent *);
      void leaveEvent(QEvent *);
      void paintEvent(QPaintEvent *);
      void resizeEvent(QResizeEvent *);

    private:
      QBitmap bitmap;

      bool mouseOver;
      bool mouseDown;
  };

  class KapturButtonClose : public KapturButton
  {
    Q_OBJECT

    public:
      KapturButtonClose(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void closeWindow();
  };

  class KapturButtonHelp : public KapturButton
  {
    Q_OBJECT

    public:
      KapturButtonHelp(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void help();
  };

  class KapturButtonIconify : public KapturButton
  {
    Q_OBJECT

    public:
      KapturButtonIconify(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void iconify();
  };

  class KapturButtonLower : public KapturButton
  {
    Q_OBJECT

    public:
      KapturButtonLower(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void lowerWindow();
  };

  class KapturButtonMaximize : public KapturButton
  {
    Q_OBJECT

    public:
      KapturButtonMaximize(bool maximised, QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    protected slots:
      void slotMaximizeChange(bool);

    signals:
      void maximize(int mode);
  };

  class KapturButtonSticky : public KapturButton
  {
    Q_OBJECT

    public:
      KapturButtonSticky(bool sticky, QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    protected slots:
      void slotStickyChange(bool);

    signals:
      void toggleSticky();
  };

  class KapturButtonStaysOnTop : public KapturButton
  {
    Q_OBJECT

    public:
      KapturButtonStaysOnTop(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void toggleStaysOnTop();
  };
}

#endif /* _LOGIKBUTTONS_H_ */

